% Given to us by T070247
f1 = 9.096e6;
f2 = 45.481e6;
frequencies = [-f2 -f1 0 f1 f2];
TotalPower = [63.8 .16 82 .16 100];

FSR = 252e6;
Lcav = c / (2*FSR);
Lcav = 0.469;

%% some functions we'll need
g_factor = @(L,R) 1-L/R;
GouyPhase = @(L,R) acos(g_factor(L,R))*180/pi;
waist = @(L,R) sqrt(1.064e-6*cavHG(L, R, R)/pi);

%% Generate the powers in each higher order mode
HOMindex      = 0:7;
MisAlignPower      = 0.02;
alpha = 1 / (1/MisAlignPower + 1);
HOMpower      = alpha.^(HOMindex);
HOMpower(1) = 0;
ModeMisMatchPercent = 0.05;
alpha = (1+sqrt(ModeMisMatchPercent) + ModeMisMatchPercent/2);

ModeMisMatchPower = [kappa(alpha,0)^4 0, ...
                     2*(kappa(alpha,0)*kappa(alpha,2))^2 0, ...
                     2*(kappa(alpha,0)*kappa(alpha,4))^2+kappa(alpha,2)^4 0, ...
                     2*(kappa(alpha,0)*kappa(alpha,6))^2+2*(kappa(alpha,2)*kappa(alpha,4))^2 0];
                 
HOMpower = HOMpower + ModeMisMatchPower;
HOMpower(1) = 1 - MisAlignPower - ModeMisMatchPercent;

HOMandRF = reshape(HOMpower'*TotalPower, [], 1);
FreqAndHOMidx = [ -f2*ones(8,1) HOMindex';
                  -f1*ones(8,1) HOMindex';
                    0*ones(8,1) HOMindex';
                   f1*ones(8,1) HOMindex';
                   f2*ones(8,1) HOMindex'];

    

%% Input spectrum
% Here we calculate the aLIGO input spectrum assuming L1 OMC
% characteristics
L1gouy = 2*43.8 * pi/180;    % Round trip Gouy phase for L1 eLIGO OMC
L1FSR  = 295.2e6;
L1F    = 360;

df = -L1FSR:1000:L1FSR;

sbPower = makeSB(df,HOMandRF, FreqAndHOMidx, L1FSR, L1F, L1gouy);
totalPower = sum(sbPower,2);
extraPower = totalPower - HOMandRF(17)*makeFringe(df,0, L1FSR, L1F, L1gouy, 0).';

% display it
figure(1);
clf;

plotData(df, totalPower, extraPower, sbPower);

%% Parameter scan
gPhaseScan = (65:0.1:85)*pi/180;
RR = [1 1.5  2  2.5 3];
L = 0.35:0.001:0.9;
% multiple g
gPower = zeros(length(L),length(RR));
thisF = 400;

for rr = 1:length(RR)
    g = 1-L/RR(rr);
    gPhaseScan = 2*acos(g);

    nG = length(gPhaseScan);

    for jj = 1:nG
        for ii = 1:length(HOMandRF)
            fRF = FreqAndHOMidx(ii,1);
            n   = FreqAndHOMidx(ii,2);
            thisFSR = c/(2*L(jj));
            gPower(jj,rr) = HOMandRF(ii)*makeFringe(0, fRF, thisFSR, thisF, gPhaseScan(jj), n)+gPower(jj,rr);
        end
        gPower(jj,rr) = gPower(jj,rr) - HOMandRF(17)*makeFringe(0,0,thisFSR, thisF, gPhaseScan(jj),0);
    end
end



figure(4)
clf;
L1omcL = .508;
FiveL  = 0.4;
ThreeL = 0.83;
set(gca, 'FontSize', 16);
%semilogy(gPhaseScan*180/pi, gPower);
junkPower = sum(HOMandRF) - HOMandRF(17);
L1fact    = interp1(L,  1./gPower*junkPower, L1omcL);
FiveFact  = interp1(L,  1./gPower*junkPower, FiveL);
ThreeFact = interp1(L,  1./gPower*junkPower, ThreeL);

a = plot(L, 1./gPower*junkPower, '-', ...
         L1omcL, L1fact(3), 'or', ...
        FiveL, FiveFact(3), 'vr', ...
        ThreeL, ThreeFact(3), 'dr');
set(a, 'MarkerFaceColor', [1 0 0], 'MarkerSize', 10);

ylabel('Attenuation');
xlabel('Length [m]');
legend('1.0 m', '1.5 m', '2.0 m', '2.5 m', '3.0 m', 'Location', 'NorthWest');
axis('tight');

%% Different Gouy Phase contributions
figure(2)
goodGouy = 109*pi/180;
goodG = cos(goodGouy/2);
R = 2;
L = (1-goodG)*R; 
FSR = c/(2*L);
Finesse = 400;
df = -FSR:1e3:FSR;

sbPower = makeSB(df,HOMandRF, FreqAndHOMidx, FSR, Finesse, goodGouy);
totalPower = sum(sbPower,2);
extraPower = totalPower - HOMandRF(17)*makeFringe(df,0, FSR, Finesse, goodGouy, 0).';

plotData(df, totalPower, extraPower, sbPower);

%% This is the good Gouy phase we like
figure(3)
R = 2;
L = Lcav;
g = 1-L/R;
goodGouy = 2*acos(g);
FSR = c/(2*L);
df = -FSR:1e3:FSR;

sbPower = makeSB(df,HOMandRF, FreqAndHOMidx, FSR, Finesse, goodGouy);
totalPower = sum(sbPower,2);
extraPower = totalPower - HOMandRF(17)*makeFringe(df,0, FSR, Finesse, goodGouy, 0).';

plotData(df, totalPower, extraPower, sbPower);

%% As a function of ROC, this is the extra power

R = 2 + [-1.1:0.01:1.1];
L = Lcav;
g = 1-L./R;
goodGouy = 2*acos(g);
FSR = c/(2*L);
df = 0;
extraPower = [];
sbPower = [];
totalPower = [];

for ii = 1:length(R)
    sbPower(ii,:) = makeSB(df,HOMandRF, FreqAndHOMidx, FSR, Finesse, goodGouy(ii));
    totalPower(ii) = sum(sbPower(ii,:),2);
    extraPower(ii) = totalPower(ii)-sbPower(ii,3);
end

figure(55)
semilogy(R, extraPower);
axis([R(1) R(end) min(extraPower)/2 max(extraPower)*2])

%% Mode spacing
% for each HOM of each RF,  calculate the spacing for each length
L = Lcav;
FSR = c./(2*L);
R = 0.9:0.001:2.5;
g = 1-L./R;
phi_g = 2*acos(g);

minSpacing = [];
for ii = 1:length(phi_g)
    df =  FreqAndHOMidx(:,1)+FreqAndHOMidx(:,2)*phi_g(ii)/(2*pi)*FSR;
    spacing = mod(df, FSR);
    spacing(17) = [];
    [minSpacing(ii,1) minSpacing(ii,2)] = min(abs(spacing/FSR));
end

figure(5)
clf;

%subplot(2,1,1)
set(gca, 'FontSize', 16);
plot(R, minSpacing(:,1), '-', ...
     R, f1./FSR, 'k--');
 
xlabel('Radius [m]');
ylabel('Nearest mode [\delta f / FSR]');
axis('tight');

%subplot(2,1,2)
%plot(L, minSpacing(:,2))

%% Full range
if  0 %(exist( 'bigMat.mat', 'file'))
    load('bigMat');
else
    
    tic;

    L = 0.4:0.001:0.75;
    R = 0.45:0.01:2.25;
    bigMat = zeros(length(L), length(R));

    for ll = 1:length(L)
        for rr = 1:length(R)
            FSR = c/(2*L(ll));
            myG = 2*pi/180*GouyPhase(L(ll),R(rr));
            sbPower = makeSB(0, HOMandRF, FreqAndHOMidx, FSR, Finesse, myG);
            bigMat(ll,rr) = sum(sbPower) - sbPower(3);
        end
    end
    save('BigMat.mat','bigMat','R','L','FSR','Finesse','FreqAndHOMidx','HOMandRF');
toc
end

%%
figure(2)


clf;
set(gca, 'FontSize', 16);

minVal = min(min(bigMat));

imagesc(R,L, log10(bigMat-minVal))
hold on;
plot(R, Lcav*ones(size(R)), 'LineWidth', 3);
gp= 1-0.595/1.944;
%plot(R, R*(1-gp),'r', 'LineWidth', 3)
hold off;

caxis([-5 0])
colorbar
ylabel('Length [m]');
xlabel('Radius [m]');
title('SB and HOM power transmission')
shg

%%
figure(33)
[mm,ii] = min(abs(R-2));
semilogy(L, bigMat(:,ii))
%% 
figure(4000)
clf;
set(gca, 'FontSize', 16);
f = [-25:.1:380]*1e6;
ll = [.7 0.469];
rr = [1 2];
FSR = c./(2*ll(2));

if 0 
    subplot(2,1,1)
set(gca, 'FontSize', 16);
semilogy(f/FSR, makeSB(f,  HOMandRF, FreqAndHOMidx, c/(2*ll(1)), 400, pi/180*2*GouyPhase(ll(1),rr(1) ) ), ...
    'LineWidth', 3)
axis([-.1 1.1 1e-6 1e2])
title('1 m ROC');
ylabel('Transmitted power');
end
%subplot(2,1,2)
set(gca, 'FontSize', 16);
semilogy(f/FSR, makeSB(f,  HOMandRF, FreqAndHOMidx, c/(2*ll(2)), 400, pi/180*2*GouyPhase(ll(2),rr(2) ) ), ...
    'LineWidth', 3)
axis([-.1 1.1 1e-6 1e2])
title ('2m ROC');
xlabel('Detuning [f/FSR]')
ylabel('Transmitted power');

