function [df, n_min] = distNearestMode(L, R, Finesse, Frequency, Nrange)
% function [df, n_min] = distNearestMode(L, R, Finesse, Frequency, Nrange)
%
% returns the lowest order HOM for the cavity of 
%
%  L          length      [m]
%  R          mirror ROC  [m]
%  Finesse    Finesse
%  Frequency  RF sideband frequency [Hz]
%  Nrange     Number of FSRs away from resonance 
%
%  Calculates the distance to the closest mode within Nrange HOMs of the
%  TEM00 carrier field.  The distance is returned as the number of
%  linewidths of the cavity.
%
%  Assumes a linear,  symmetric cavity
%

c = 299692458;            % m/s
FSR = c/(2*L);            % Free spectral range,  Hz
g = 1-L/R;                % g-factor
Phi_g = 2*180/pi*acos(g); % Round trip HOM phase shift [deg]
%Phi_g = bowTieGouy(R,L/2, 0.04);
f_hom = Phi_g * FSR/360;  % HOM frequency shift [Hz]
f_bw = FSR/Finesse/2;     % linewidth (Hz)

f_res = @(N_hom) mod(N_hom*f_hom + Frequency, FSR);

df = 1000;
n_min = 0;
if Frequency ~= 0
    n_start = 0;
else
    n_start = 1;
end

for nn = n_start:Nrange
    this_df = min([f_res(nn) FSR-f_res(nn)])/f_bw;
    
    if this_df < df 
       	df = this_df;
        n_min = nn;

    end
end
        



